﻿<?php
// edit_finance.php
session_start();
require_once '../config.php';

if (!isset($_SESSION['user'])) {
    header("Location: ../login.php");
    exit;
}

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: list_finance.php");
    exit;
}

$id = (int)$_GET['id'];
$conn = get_db_connection();
$conn->set_charset("utf8mb4");

$success = '';
$error = '';

$stmt = $conn->prepare("SELECT * FROM financial_records WHERE id = ?");
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();
$finance = $result->fetch_assoc();

if (!$finance) {
    header("Location: list_finance.php");
    exit;
}

// 提交处理
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $record_type = $_POST['record_type'] ?? '';
    $category = $_POST['category'] ?? '';
    $amount = floatval($_POST['amount'] ?? 0);
    $payment_method = $_POST['payment_method'] ?? '';
    $description = $_POST['description'] ?? '';
    $created_at = $_POST['created_at'] ?? '';

    if (!empty($created_at)) {
        $created_at = str_replace('T', ' ', $created_at);
    } else {
        $created_at = date('Y-m-d H:i:s');
    }

    if ($record_type && $category && $amount > 0 && $payment_method) {
        $stmt = $conn->prepare("UPDATE financial_records SET record_type = ?, category = ?, amount = ?, payment_method = ?, description = ?, created_at = ? WHERE id = ?");
        $stmt->bind_param("ssdsssi", $record_type, $category, $amount, $payment_method, $description, $created_at, $id);

        if ($stmt->execute()) {
            header("Location: list_finance.php?message=" . urlencode("✅ 修改成功"));
            exit;
        } else {
            $error = "❌ 数据库错误: " . $stmt->error;
        }
    } else {
        $error = "❌ 请填写完整内容";
    }
}

// 日期格式化
function formatDatetimeLocal($dt)
{
    return date('Y-m-d\TH:i', strtotime($dt));
}
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>编辑财务记录</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>编辑财务记录</h2>
        <a href="list_finance.php" class="btn btn-secondary">返回列表</a>
    </div>

    <div class="container">
        <?php if ($error): ?>
            <div class="message" style="background-color: #f8d7da; color: #721c24;"><?= $error ?></div>
        <?php endif; ?>

        <form method="post">
            <div class="form-row">
                <div class="form-col">
                    <label>类型:</label>
                    <select name="record_type" required>
                        <option value="">请选择</option>
                        <option value="收入" <?= $finance['record_type'] === '收入' ? 'selected' : '' ?>>收入</option>
                        <option value="支出" <?= $finance['record_type'] === '支出' ? 'selected' : '' ?>>支出</option>
                    </select>
                </div>
                <div class="form-col">
                    <label>分类:</label>
                    <input type="text" name="category" required value="<?= htmlspecialchars($finance['category']) ?>">
                </div>
            </div>

            <div class="form-row">
                <div class="form-col">
                    <label>金额(元):</label>
                    <input type="number" step="0.01" name="amount" required value="<?= $finance['amount'] ?>">
                </div>
                <div class="form-col">
                    <label>支付方式:</label>
                    <select name="payment_method" required>
                        <?php foreach (['现金', '微信', '支付宝', '银行卡', '转账', '其他'] as $m): ?>
                            <option value="<?= $m ?>" <?= $finance['payment_method'] === $m ? 'selected' : '' ?>><?= $m ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>

            <div class="form-group">
                <label>说明:</label>
                <textarea name="description"><?= htmlspecialchars($finance['description']) ?></textarea>
            </div>

            <div class="form-group">
                <label>记录时间:</label>
                <input type="datetime-local" name="created_at" value="<?= formatDatetimeLocal($finance['created_at']) ?>">
            </div>

            <div class="btn-group">
                <button type="submit" class="btn">保存修改</button>
                <button type="reset" class="btn btn-secondary">重置</button>
            </div>
        </form>
    </div>
</body>

</html>