<?php
session_start();
if (!isset($_SESSION['user'])) {
    header("Location: login.php");
    exit;
}

// 引入数据库配置文件
require_once 'config.php';

// 数据库连接
$conn = get_db_connection();

$username = $_SESSION['user']['username'];
$real_name = $_SESSION['user']['real_name'] ?? $username; // 从会话中获取真实姓名，如果没有就显示用户名
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>CA417-副食品行业进销存管理系统</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Microsoft YaHei', Arial, sans-serif;
            background: linear-gradient(135deg, #7fd978, #2b9348);
            padding: 30px;
            color: #333;
            min-height: 100vh;
        }

        .header {
            text-align: center;
            margin-bottom: 40px;
        }

        .header h1 {
            font-size: 2.2rem;
            margin-bottom: 10px;
            color: white;
        }

        .header p {
            font-size: 1.1rem;
            color: rgba(255, 255, 255, 0.9);
        }

        .modules-container {
            max-width: 1200px;
            margin: 0 auto;
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(280px, 1fr));
            gap: 25px;
            padding: 20px;
        }

        /* 统一模块样式 
         * 优点：
         * 1. 保持界面风格统一
         * 2. 简化CSS代码，易于维护
         * 3. 新增模块时无需添加特定样式
         */
        .module-card {
            background-color: white;
            border-radius: 10px;
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            transition: transform 0.3s, box-shadow 0.3s;
            text-decoration: none;
            color: #333;
            display: flex;
            flex-direction: column;
            height: 250px;
            border: 1px solid #eaeaea;
        }

        .module-card:hover {
            transform: translateY(-10px);
            box-shadow: 0 10px 20px rgba(0, 0, 0, 0.15);
            border-color: #2b9348;
        }

        .module-header {
            background-color: #2b9348;
            color: white;
            padding: 20px;
            text-align: center;
        }

        .module-title {
            font-size: 1.3rem;
            font-weight: 500;
        }

        .module-body {
            padding: 20px;
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
        }

        .module-description {
            color: #666;
            margin-bottom: 15px;
            line-height: 1.5;
        }

        .module-footer {
            text-align: center;
            margin-top: auto;
        }

        .enter-btn {
            display: inline-block;
            background-color: #2b9348;
            color: white;
            padding: 8px 20px;
            border-radius: 4px;
            text-decoration: none;
            transition: background-color 0.3s;
        }

        .enter-btn:hover {
            background-color: #3c8c51;
        }

        .user-bar {
            display: flex;
            justify-content: flex-end;
            margin-bottom: 10px;
        }

        .user-info {
            background-color: white;
            padding: 10px 20px;
            border-radius: 4px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            display: flex;
            align-items: center;
        }

        .user-name {
            margin-right: 15px;
        }

        .logout-btn {
            color: #dc3545;
            text-decoration: none;
        }

        .logout-btn:hover {
            text-decoration: underline;
        }

        /* 系统标题样式 */
        .system-title {
            text-align: center;
            margin-bottom: 20px;
        }

        .system-title h1 {
            color: white;
            font-size: 40px;
            text-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
            letter-spacing: 10px;
        }
    </style>
</head>

<body>
    <div class="user-bar">
        <div class="user-info">
            <span class="user-name">当前用户：<?= htmlspecialchars($real_name) ?></span>

            <a href="logout.php" class="logout-btn">退出</a>
        </div>
    </div>

    <div class="system-title">
        <h1>CA417-副食品行业进销存管理系统</h1>
    </div>

    <div class="modules-container">
        <!-- 商品管理模块 -->
        <div class="module-card">
            <div class="module-header">
                <div class="module-title">商品管理</div>
            </div>
            <div class="module-body">
                <div class="module-description">
                    管理商品信息、分类、价格等，支持添加、编辑和查询商品。
                </div>
                <div class="module-footer">
                    <a href="product/index.php" class="enter-btn">立即进入</a>
                </div>
            </div>
        </div>

        <!-- 财务管理模块 -->
        <div class="module-card">
            <div class="module-header">
                <div class="module-title">财务管理</div>
            </div>
            <div class="module-body">
                <div class="module-description">
                    管理财务数据，包括收入、支出、利润等，支持添加、编辑和查询财务数据。
                </div>
                <div class="module-footer">
                    <a href="finance/index.php" class="enter-btn">立即进入</a>
                </div>
            </div>
        </div>

        <!-- 库存管理模块 -->
        <div class="module-card">
            <div class="module-header">
                <div class="module-title">库存管理</div>
            </div>
            <div class="module-body">
                <div class="module-description">
                    管理库存、多仓库、供应商、库存调拨，支持添加、编辑和查询库存数据。
                </div>
                <div class="module-footer">
                    <a href="inventory/index.php" class="enter-btn">立即进入</a>
                </div>
            </div>
        </div>

        <!-- 用户管理模块 -->
        <div class="module-card">
            <div class="module-header">
                <div class="module-title">用户管理</div>
            </div>
            <div class="module-body">
                <div class="module-description">
                    管理系统用户信息，包括账号、权限、状态等，支持编辑与启用/禁用。
                </div>
                <div class="module-footer">
                    <a href="user/index.php" class="enter-btn">立即进入</a>
                </div>
            </div>
        </div>
    </div>
</body>

</html>