<?php
session_start();
if (!isset($_SESSION['user'])) {
    header("Location: ../login.php");
    exit;
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 获取仓库ID
$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if ($id <= 0) {
    exit('❌ 无效的仓库ID');
}

// 查询仓库信息
$stmt = $conn->prepare("SELECT * FROM warehouses WHERE id = ?");
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    exit('❌ 仓库不存在');
}

$warehouse = $result->fetch_assoc();
$stmt->close();
$conn->close();
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑仓库</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>编辑仓库</h2>
        <a href="warehouse.php" class="btn btn-secondary">返回列表</a>
    </div>

    <!-- 消息显示 -->
    <div id="message-container" class="message" style="display: none;">
        <span id="message-text"></span>
        <button onclick="document.getElementById('message-container').style.display='none'">×</button>
    </div>

    <div class="container">
        <form action="save_warehouse.php" method="post" target="response-frame" id="warehouse-form">
            <input type="hidden" name="action" value="edit">
            <input type="hidden" name="id" value="<?= $id ?>">

            <div class="form-row">
                <div class="form-col">
                    <label>仓库名称：</label>
                    <input type="text" name="name" value="<?= htmlspecialchars($warehouse['name']) ?>" required>
                </div>
                <div class="form-col">
                    <label>仓库地址：</label>
                    <input type="text" name="location" value="<?= htmlspecialchars($warehouse['location'] ?? '') ?>">
                </div>
            </div>
            <div class="form-row">
                <div class="form-col">
                    <label>负责人：</label>
                    <input type="text" name="manager" value="<?= htmlspecialchars($warehouse['manager'] ?? '') ?>">
                </div>
                <div class="form-col">
                    <label>联系电话：</label>
                    <input type="text" name="phone" value="<?= htmlspecialchars($warehouse['phone'] ?? '') ?>">
                </div>
            </div>
            <div class="btn-group">
                <button type="button" class="btn btn-secondary" onclick="window.location.href='warehouse.php'">取消</button>
                <button type="submit" class="btn btn-success">保存</button>
            </div>
        </form>
    </div>

    <!-- 隐藏iframe用于接收返回 -->
    <iframe name="response-frame" id="response-frame" style="display:none;"></iframe>

    <script>
        // 提交完成后显示返回消息
        document.getElementById('response-frame').onload = function() {
            try {
                var response = this.contentWindow.document.body.innerHTML;
                if (response.includes("✅")) {
                    showMessage(response);
                    // 1秒后返回列表页
                    setTimeout(function() {
                        window.location.href = 'warehouse.php';
                    }, 1000);
                } else if (response.includes("❌")) {
                    showMessage(response);
                }
            } catch (e) {}
        };

        function showMessage(text) {
            const box = document.getElementById("message-container");
            document.getElementById("message-text").innerText = text;
            box.style.display = "flex";
            setTimeout(() => box.style.display = "none", 3000);
        }
    </script>
</body>

</html>