<?php
// get_product_units.php - 获取商品单位信息

session_start();
if (!isset($_SESSION['user'])) {
    header('Content-Type: application/json');
    echo json_encode(['error' => '未登录']);
    exit;
}

// 引入数据库配置文件
require_once '../config.php';

// 确保有输出缓冲区可供清理
ob_start();

try {
    // 验证商品ID
    if (!isset($_GET['product_id']) || !is_numeric($_GET['product_id'])) {
        // 确保在返回JSON前清理缓冲区
        if (ob_get_length()) {
            ob_clean();
        }
        header('Content-Type: application/json');
        echo json_encode(['error' => '无效的商品ID']);
        exit;
    }

    $product_id = intval($_GET['product_id']);

    // 数据库连接
    $conn = get_db_connection();

    // 查询商品的所有单位
    $sql = "SELECT id, product_id, unit_type, unit_name, ratio FROM product_units WHERE product_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $product_id);
    $stmt->execute();
    $result = $stmt->get_result();

    $units = [];
    while ($row = $result->fetch_assoc()) {
        $units[] = $row;
    }

    // 关闭数据库连接
    $stmt->close();
    $conn->close();

    // 确保在返回JSON前清理缓冲区
    if (ob_get_length()) {
        ob_clean();
    }

    // 返回JSON格式的单位数据
    header('Content-Type: application/json');
    echo json_encode($units);
    exit;
} catch (Exception $e) {
    // 确保在返回JSON前清理缓冲区
    if (ob_get_length()) {
        ob_clean();
    }

    // 返回错误信息
    header('Content-Type: application/json');
    echo json_encode(['error' => '获取单位信息失败', 'message' => $e->getMessage()]);
    exit;
}
