<?php
session_start();
if (!isset($_SESSION['user'])) {
    header("Location: ../login.php");
    exit;
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 初始化变量
$selected_product = isset($_GET['product_id']) ? intval($_GET['product_id']) : '';
$source_warehouse = isset($_GET['warehouse_id']) ? intval($_GET['warehouse_id']) : '';
$target_warehouse = '';
$quantity = '';
$unit_type = 'base';

// 获取仓库列表
$warehouses = [];
$warehouseResult = $conn->query("SELECT id, name FROM warehouses ORDER BY name");
if ($warehouseResult) {
    while ($row = $warehouseResult->fetch_assoc()) {
        $warehouses[$row['id']] = $row;
    }
}

// 如果指定了商品ID，获取该商品有库存的仓库
$productWarehouses = [];
$productInfo = null;
$productUnits = []; // 新增：存储商品的所有单位

if ($selected_product) {
    // 获取商品信息
    $productSql = "SELECT p.id, p.product_code, p.product_name, p.unit, p.multi_unit 
                   FROM products p WHERE p.id = ?";
    $productStmt = $conn->prepare($productSql);
    $productStmt->bind_param("i", $selected_product);
    $productStmt->execute();
    $productResult = $productStmt->get_result();

    if ($productResult->num_rows > 0) {
        $productInfo = $productResult->fetch_assoc();

        // 新增：如果是多单位商品，获取所有单位
        if ($productInfo['multi_unit'] == 1) {
            $unitsSql = "SELECT unit_name, ratio FROM product_units 
                         WHERE product_id = ? AND unit_type = 'sub'";
            $unitsStmt = $conn->prepare($unitsSql);
            $unitsStmt->bind_param("i", $selected_product);
            $unitsStmt->execute();
            $unitsResult = $unitsStmt->get_result();

            while ($unitRow = $unitsResult->fetch_assoc()) {
                $productUnits[$unitRow['unit_name']] = $unitRow['ratio'];
            }
        }

        // 获取该商品有库存的仓库
        $stockSql = "SELECT s.warehouse_id, w.name as warehouse_name, s.base_quantity 
                     FROM inventory_stock s 
                     JOIN warehouses w ON s.warehouse_id = w.id 
                     WHERE s.product_id = ? AND s.base_quantity > 0";
        $stockStmt = $conn->prepare($stockSql);
        $stockStmt->bind_param("i", $selected_product);
        $stockStmt->execute();
        $stockResult = $stockStmt->get_result();

        while ($row = $stockResult->fetch_assoc()) {
            $productWarehouses[$row['warehouse_id']] = [
                'id' => $row['warehouse_id'],
                'name' => $row['warehouse_name'],
                'stock' => $row['base_quantity']
            ];
        }
    }
}

// 处理表单提交
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $source_warehouse_id = isset($_POST['source_warehouse_id']) ? intval($_POST['source_warehouse_id']) : 0;
    $target_warehouse_id = isset($_POST['target_warehouse_id']) ? intval($_POST['target_warehouse_id']) : 0;

    // 检查是否有商品数据
    $products = isset($_POST['products']) ? $_POST['products'] : [];
    $quantities = isset($_POST['quantities']) ? $_POST['quantities'] : [];
    $unit_types = isset($_POST['unit_types']) ? $_POST['unit_types'] : [];

    // 如果是旧版单商品模式
    if (empty($products) && isset($_POST['product_id'])) {
        $product_id = intval($_POST['product_id']);
        $quantity = isset($_POST['quantity']) ? floatval($_POST['quantity']) : 0;
        $unit_type = isset($_POST['unit_type']) ? $_POST['unit_type'] : 'base';

        if ($product_id > 0) {
            $products = [$product_id];
            $quantities = [$quantity];
            $unit_types = [$unit_type];
        }
    }

    $selected_product = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
    $source_warehouse = $source_warehouse_id;
    $target_warehouse = $target_warehouse_id;

    // 验证输入
    if ($source_warehouse_id <= 0) {
        $message = '❌ 请选择源仓库!';
    } elseif ($target_warehouse_id <= 0) {
        $message = '❌ 请选择目标仓库!';
    } elseif ($source_warehouse_id == $target_warehouse_id) {
        $message = '❌ 源仓库和目标仓库不能相同!';
    } elseif (empty($products)) {
        $message = '❌ 请至少选择一个商品!';
    } else {
        // 开始事务
        $conn->begin_transaction();
        $success = true;
        $errors = [];

        try {
            // 遍历所有商品进行调拨
            for ($i = 0; $i < count($products); $i++) {
                $product_id = intval($products[$i]);
                $quantity = floatval($quantities[$i]);
                $unit_type = $unit_types[$i];

                // 验证单个商品
                if ($product_id <= 0) {
                    $errors[] = '商品ID无效';
                    $success = false;
                    continue;
                }

                if ($quantity <= 0) {
                    $errors[] = '商品 ID:' . $product_id . ' 的调拨数量无效';
                    $success = false;
                    continue;
                }

                // 获取基本单位数量
                $base_quantity = $quantity;

                // 如果不是基本单位，需要进行换算
                if ($unit_type !== 'base') {
                    // 查询单位换算比例
                    $ratioSql = "SELECT ratio FROM product_units WHERE product_id = ? AND unit_name = ? AND unit_type = 'sub'";
                    $ratioStmt = $conn->prepare($ratioSql);
                    $ratioStmt->bind_param("is", $product_id, $unit_type);
                    $ratioStmt->execute();
                    $ratioResult = $ratioStmt->get_result();

                    if ($ratioResult->num_rows > 0) {
                        $ratio = $ratioResult->fetch_assoc()['ratio'];
                        $base_quantity = $quantity * $ratio;
                    }
                }

                // 检查源仓库是否有足够的库存
                $checkSql = "SELECT id, base_quantity FROM inventory_stock WHERE product_id = ? AND warehouse_id = ?";
                $checkStmt = $conn->prepare($checkSql);
                $checkStmt->bind_param("ii", $product_id, $source_warehouse_id);
                $checkStmt->execute();
                $checkResult = $checkStmt->get_result();

                if ($checkResult->num_rows == 0) {
                    $errors[] = '商品 ID:' . $product_id . ' 在源仓库没有库存记录';
                    $success = false;
                    continue;
                }

                $sourceStock = $checkResult->fetch_assoc();
                if ($sourceStock['base_quantity'] < $base_quantity) {
                    $errors[] = '商品 ID:' . $product_id . ' 的源仓库库存不足';
                    $success = false;
                    continue;
                }

                // 从源仓库减少库存
                $newSourceQuantity = $sourceStock['base_quantity'] - $base_quantity;
                $updateSourceSql = "UPDATE inventory_stock SET base_quantity = ?, updated_by = ?, last_updated = NOW() WHERE id = ?";
                $updateSourceStmt = $conn->prepare($updateSourceSql);
                $userId = $_SESSION['user']['id'];
                $updateSourceStmt->bind_param("dii", $newSourceQuantity, $userId, $sourceStock['id']);
                $updateSourceStmt->execute();

                // 检查目标仓库是否已有该商品库存记录
                $checkTargetSql = "SELECT id, base_quantity FROM inventory_stock WHERE product_id = ? AND warehouse_id = ?";
                $checkTargetStmt = $conn->prepare($checkTargetSql);
                $checkTargetStmt->bind_param("ii", $product_id, $target_warehouse_id);
                $checkTargetStmt->execute();
                $checkTargetResult = $checkTargetStmt->get_result();

                if ($checkTargetResult->num_rows > 0) {
                    // 更新目标仓库库存
                    $targetStock = $checkTargetResult->fetch_assoc();
                    $newTargetQuantity = $targetStock['base_quantity'] + $base_quantity;
                    $updateTargetSql = "UPDATE inventory_stock SET base_quantity = ?, updated_by = ?, last_updated = NOW() WHERE id = ?";
                    $updateTargetStmt = $conn->prepare($updateTargetSql);
                    $updateTargetStmt->bind_param("dii", $newTargetQuantity, $userId, $targetStock['id']);
                    $updateTargetStmt->execute();
                } else {
                    // 在目标仓库新增库存记录
                    $insertTargetSql = "INSERT INTO inventory_stock (product_id, warehouse_id, base_quantity, updated_by) VALUES (?, ?, ?, ?)";
                    $insertTargetStmt = $conn->prepare($insertTargetSql);
                    $insertTargetStmt->bind_param("iidi", $product_id, $target_warehouse_id, $base_quantity, $userId);
                    $insertTargetStmt->execute();
                }
            }

            if ($success) {
                // 提交事务
                $conn->commit();

                // 修改：确保消息正确编码并传递
                $success_message = '✅ 库存调拨成功!';
                header("Location: inventory_stock.php?message=" . rawurlencode($success_message) . "&refresh=1");
                exit;
            } else {
                // 如果有任何一个商品调拨失败，回滚所有操作
                $conn->rollback();
                $message = '❌ 调拨失败: ' . implode('; ', $errors);
            }
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $message = '❌ 调拨失败: ' . $e->getMessage();
        }
    }
}

$conn->close();
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>库存调拨</title>
    <link rel="stylesheet" href="style.css">
    <link rel="stylesheet" href="./css/inventory_transfer_form.css">
</head>

<body>
    <div class="header">
        <h2>库存调拨</h2>
        <a href="inventory_stock.php" class="btn btn-secondary">返回库存列表</a>
    </div>

    <!-- 消息显示 -->
    <?php if (!empty($message)): ?>
        <div id="message-container" class="message <?= strpos($message, '✅') === 0 ? 'success' : 'error' ?>" style="display: flex;">
            <span id="message-text"><?= $message ?></span>
            <button onclick="document.getElementById('message-container').style.display='none'">×</button>
        </div>
    <?php endif; ?>

    <div class="container">
        <form action="" method="post" id="transfer-form">
            <!-- 调整表单布局，选择商品和仓库 -->
            <?php if ($selected_product && $productInfo): ?>
                <!-- 显示已选择的商品信息 -->
                <div class="form-row" style="margin-top: 20px;">
                    <div class="form-col" style="flex-basis: 100%">
                        <label>选择的商品：</label>
                        <div class="search-select-container">
                            <input type="text" class="search-input" value="<?= htmlspecialchars($productInfo['product_name']) ?> (<?= htmlspecialchars($productInfo['product_code']) ?>)" disabled>
                            <input type="hidden" id="product_id" name="product_id" value="<?= $selected_product ?>">
                        </div>
                    </div>
                </div>

                <div class="form-row" style="margin-top: 20px;">
                    <div class="form-col">
                        <label>源仓库：</label>
                        <select name="source_warehouse_id" id="source_warehouse_id" class="form-select" required>
                            <option value="">请选择源仓库</option>
                            <?php foreach ($productWarehouses as $warehouse): ?>
                                <option value="<?= $warehouse['id'] ?>"
                                    <?= $source_warehouse == $warehouse['id'] ? 'selected' : '' ?>
                                    data-stock="<?= $warehouse['stock'] ?>">
                                    <?= htmlspecialchars($warehouse['name']) ?> (库存: <span class="stock-number"><?= $warehouse['stock'] ?></span> <?= $productInfo['unit'] ?>
                                    <?php if ($productInfo['multi_unit'] == 1 && !empty($productUnits)): ?>
                                        <?php foreach ($productUnits as $unitName => $ratio): ?>
                                            , <span class="stock-number"><?= number_format($warehouse['stock'] / $ratio, 2) ?></span> <?= $unitName ?>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                    )
                                </option>
                            <?php endforeach; ?>
                        </select>
                        <p class="hint">请选择有该商品库存的源仓库</p>
                    </div>
                    <div class="form-col">
                        <label>目标仓库：</label>
                        <select name="target_warehouse_id" id="target_warehouse_id" class="form-select" required>
                            <option value="">请选择目标仓库</option>
                            <?php foreach ($warehouses as $warehouse): ?>
                                <?php
                                $targetStock = 0;
                                foreach ($productWarehouses as $pw) {
                                    if ($pw['id'] == $warehouse['id']) {
                                        $targetStock = $pw['stock'];
                                        break;
                                    }
                                }
                                ?>
                                <option value="<?= $warehouse['id'] ?>"
                                    <?= $target_warehouse == $warehouse['id'] ? 'selected' : '' ?>
                                    data-stock="<?= $targetStock > 0 ? '1' : '0' ?>">
                                    <?= htmlspecialchars($warehouse['name']) ?> (库存: <span class="stock-number"><?= $targetStock ?></span> <?= $productInfo['unit'] ?>
                                    <?php if ($productInfo['multi_unit'] == 1 && !empty($productUnits)): ?>
                                        <?php foreach ($productUnits as $unitName => $ratio): ?>
                                            , <span class="stock-number"><?= number_format($targetStock / $ratio, 2) ?></span> <?= $unitName ?>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                    )
                                </option>
                            <?php endforeach; ?>
                        </select>
                        <p class="warning-text">注意: 源仓库和目标仓库不能相同</p>
                    </div>
                </div>

                <div class="form-row" style="margin-top: 20px;">
                    <div class="form-col">
                        <label>调拨数量：</label>
                        <input type="number" name="quantity" id="quantity" class="form-input" min="0.01" step="0.01"
                            placeholder="请输入调拨数量" value="<?= $quantity ?>" required>
                    </div>
                    <div class="form-col">
                        <label>单位选择：</label>
                        <select name="unit_type" id="unit_type" class="form-select">
                            <option value="base"><?= $productInfo['unit'] ?></option>
                            <?php if ($productInfo['multi_unit'] == 1 && !empty($productUnits)): ?>
                                <?php foreach ($productUnits as $unitName => $ratio): ?>
                                    <option value="<?= $unitName ?>" <?= $unit_type == $unitName ? 'selected' : '' ?>><?= $unitName ?></option>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </select>
                    </div>
                </div>

                <!-- 库存提示信息独立显示 -->
                <div class="form-row">
                    <div class="form-col" style="flex-basis: 100%">
                        <p id="stock-hint" class="stock-hint"></p>
                    </div>
                </div>

            <?php else: ?>
                <!-- 多商品调拨模式 -->

                <div class="form-row" style="margin-top: 20px;">
                    <div class="form-col">
                        <label>源仓库：</label>
                        <select name="source_warehouse_id" id="source_warehouse_id" class="form-select" required>
                            <option value="">请选择源仓库</option>
                            <?php foreach ($warehouses as $warehouse): ?>
                                <option value="<?= $warehouse['id'] ?>" <?= $source_warehouse == $warehouse['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($warehouse['name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                        <p class="hint">请先选择源仓库，然后再选择目标仓库和商品</p>
                    </div>
                    <div class="form-col">
                        <label>目标仓库：</label>
                        <select name="target_warehouse_id" id="target_warehouse_id" class="form-select" required>
                            <option value="">请选择目标仓库</option>
                            <?php foreach ($warehouses as $warehouse): ?>
                                <option value="<?= $warehouse['id'] ?>" <?= $target_warehouse == $warehouse['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($warehouse['name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                        <p class="warning-text">注意: 源仓库和目标仓库不能相同</p>
                    </div>
                </div>

                <!-- 多商品调拨模式：商品表格和添加商品按钮 -->
                <div style="margin-top: 20px;">
                    <div style="display: flex; justify-content: space-between; align-items: center;">
                        <label>调拨商品列表：</label>
                        <button type="button" id="add-product-btn" class="add-product-btn" disabled>
                            <i>+</i> 添加商品
                        </button>
                    </div>

                    <div id="no-products-msg" class="no-products-msg">请先选择源仓库后添加商品</div>

                    <table id="products-table" class="products-table" style="display: none;">
                        <thead>
                            <tr>
                                <th style="width: 40%;">商品</th>
                                <th class="quantity-col">调拨数量</th>
                                <th class="unit-col">单位</th>
                                <th class="action-col">操作</th>
                            </tr>
                        </thead>
                        <tbody id="products-body">
                            <!-- 商品行将通过JavaScript动态添加 -->
                        </tbody>
                    </table>

                    <!-- 商品选择弹窗 -->
                    <div id="product-search-container" style="display: none; margin-top: 15px;">
                        <div class="search-select-container">
                            <input type="text" id="product-search" class="search-input" placeholder="搜索商品" autocomplete="off" disabled>
                            <div id="search-results" class="search-results"></div>
                        </div>
                        <p id="product-count-hint" class="hint">请先选择源仓库</p>
                    </div>
                </div>
            <?php endif; ?>

            <div class="btn-group" style="margin-top: 30px;">
                <button type="submit" class="btn btn-success" id="submit-btn" <?= (!$selected_product) ? 'disabled' : '' ?>>提交调拨</button>
                <button type="button" class="btn btn-secondary" onclick="window.location.href='inventory_stock.php'">取消</button>
            </div>
        </form>
    </div>

    <script>
        // 初始化变量
        let warehouseProducts = [];
        let selectedProduct = null;
        let productUnits = [];
        let productsList = []; // 存储已添加的商品列表

        // 在JavaScript部分修改
        <?php if ($selected_product && $productInfo): ?>
            // 商品已预选，初始化商品信息
            selectedProduct = {
                id: <?= $selected_product ?>,
                name: "<?= addslashes($productInfo['product_name']) ?>",
                code: "<?= addslashes($productInfo['product_code']) ?>",
                unit: "<?= addslashes($productInfo['unit']) ?>",
                multiUnit: "<?= $productInfo['multi_unit'] ?>",
                units: <?= json_encode($productUnits) ?> // 新增：传递所有单位信息到前端
            };

            document.addEventListener('DOMContentLoaded', function() {
                // 源仓库选择变化时更新最大可调拨数量
                const sourceWarehouseSelect = document.getElementById('source_warehouse_id');
                const stockHint = document.getElementById('stock-hint');
                const quantityInput = document.getElementById('quantity');

                sourceWarehouseSelect.addEventListener('change', function() {
                    if (this.value) {
                        const option = this.options[this.selectedIndex];
                        const stockAmount = option.getAttribute('data-stock');

                        if (stockAmount) {
                            // 修改：显示多单位库存信息
                            let stockText = `该商品在源仓库的库存: ${stockAmount} ${selectedProduct.unit}`;

                            // 如果是多单位商品，添加其他单位的库存显示
                            if (selectedProduct.multiUnit === '1' && Object.keys(selectedProduct.units).length > 0) {
                                for (const [unitName, ratio] of Object.entries(selectedProduct.units)) {
                                    stockText += `, ${(stockAmount / ratio).toFixed(2)} ${unitName}`;
                                }
                            }

                            stockHint.textContent = stockText;
                            stockHint.style.display = 'block';
                            quantityInput.max = stockAmount;
                        } else {
                            stockHint.style.display = 'none';
                        }
                    } else {
                        stockHint.style.display = 'none';
                    }
                });

                // 目标仓库改变时检查是否与源仓库相同
                const targetWarehouseSelect = document.getElementById('target_warehouse_id');
                targetWarehouseSelect.addEventListener('change', function() {
                    const sourceWarehouse = sourceWarehouseSelect.value;
                    const targetWarehouse = this.value;

                    if (sourceWarehouse && targetWarehouse && sourceWarehouse === targetWarehouse) {
                        alert('源仓库和目标仓库不能相同!');
                        this.value = '';
                    }
                });

                // 模拟一次change事件以显示初始库存
                if (sourceWarehouseSelect.value) {
                    const event = new Event('change');
                    sourceWarehouseSelect.dispatchEvent(event);
                }
            });
        <?php else: ?>
            // 多商品调拨模式的JavaScript代码
            document.addEventListener('DOMContentLoaded', function() {
                const sourceWarehouseSelect = document.getElementById('source_warehouse_id');
                const targetWarehouseSelect = document.getElementById('target_warehouse_id');
                const addProductBtn = document.getElementById('add-product-btn');
                const productsTable = document.getElementById('products-table');
                const productsBody = document.getElementById('products-body');
                const noProductsMsg = document.getElementById('no-products-msg');
                const productSearchContainer = document.getElementById('product-search-container');
                const productSearch = document.getElementById('product-search');
                const searchResults = document.getElementById('search-results');
                const productCountHint = document.getElementById('product-count-hint');
                const submitBtn = document.getElementById('submit-btn');

                // 添加Tab键监听
                document.addEventListener('keydown', function(e) {
                    // 检测是否按下Tab键，同时没有按下Shift键
                    if (e.key === 'Tab' && !e.shiftKey) {
                        // 确保只在源仓库已选择且表单有焦点时触发
                        const activeElement = document.activeElement;
                        const formElement = document.getElementById('transfer-form');

                        if (formElement.contains(activeElement) && sourceWarehouseSelect.value && !addProductBtn.disabled) {
                            // 如果商品搜索容器没有显示，则打开它
                            if (productSearchContainer.style.display !== 'block') {
                                e.preventDefault(); // 阻止默认Tab行为
                                addProductBtn.click(); // 模拟点击添加商品按钮
                                return;
                            }
                            // 如果搜索结果已显示且焦点在搜索框上，选择第一个商品
                            else if (activeElement === productSearch && searchResults.style.display === 'block') {
                                const firstResult = searchResults.querySelector('.search-result-item');
                                if (firstResult && !firstResult.textContent.includes('没有找到匹配的商品') && !firstResult.textContent.includes('所有商品已添加')) {
                                    e.preventDefault(); // 阻止默认Tab行为
                                    firstResult.click(); // 选择第一个搜索结果
                                    return;
                                }
                            }
                        }
                    }

                    // 监听Enter键，用于在搜索框中快速选择第一个结果
                    if (e.key === 'Enter') {
                        if (document.activeElement === productSearch && searchResults.style.display === 'block') {
                            const firstResult = searchResults.querySelector('.search-result-item');
                            if (firstResult && !firstResult.textContent.includes('没有找到匹配的商品') && !firstResult.textContent.includes('所有商品已添加')) {
                                e.preventDefault(); // 阻止表单提交
                                firstResult.click(); // 选择第一个搜索结果
                            }
                        }
                    }
                });

                // 增加提示信息
                const tabTip = document.createElement('p');
                tabTip.className = 'hint';
                tabTip.style.marginTop = '5px';
                tabTip.innerHTML = '提示: 按<strong>Tab</strong>键可以快速添加商品，在搜索框中按Tab或Enter快速选择第一个结果';
                addProductBtn.parentNode.appendChild(tabTip);

                // 页面加载时，如果已有选中的源仓库ID，则加载该仓库的商品
                const selectedSourceWarehouse = '<?= $source_warehouse ?>';
                if (selectedSourceWarehouse) {
                    loadWarehouseProducts(selectedSourceWarehouse);
                    addProductBtn.disabled = false;
                }

                // 选择源仓库时加载该仓库有库存的商品
                sourceWarehouseSelect.addEventListener('change', function() {
                    const warehouseId = this.value;
                    addProductBtn.disabled = !warehouseId;

                    // 清除已添加的商品列表
                    productsList = [];
                    updateProductsTable();

                    if (warehouseId) {
                        loadWarehouseProducts(warehouseId);
                        noProductsMsg.textContent = '点击"添加商品"按钮添加调拨商品';
                    } else {
                        noProductsMsg.textContent = '请先选择源仓库后添加商品';
                        warehouseProducts = [];
                    }
                });

                // 添加商品按钮点击事件
                addProductBtn.addEventListener('click', function() {
                    if (sourceWarehouseSelect.value) {
                        // 显示商品搜索区域
                        productSearchContainer.style.display = 'block';
                        productSearch.disabled = false;
                        productSearch.focus();

                        // 显示所有可选商品
                        showAllProducts();
                    } else {
                        alert('请先选择源仓库!');
                    }
                });

                // 点击商品输入框显示所有商品
                productSearch.addEventListener('click', function() {
                    if (!this.disabled && searchResults.style.display !== 'block') {
                        showAllProducts();
                    }
                });

                // 搜索框获得焦点时显示结果
                productSearch.addEventListener('focus', function() {
                    if (!this.disabled && searchResults.style.display !== 'block') {
                        showAllProducts();
                    }
                });

                // 加载仓库商品
                function loadWarehouseProducts(warehouseId) {
                    fetch(`get_warehouse_products.php?warehouse_id=${warehouseId}`)
                        .then(response => response.json())
                        .then(data => {
                            warehouseProducts = data;
                            productCountHint.textContent = `该仓库有 ${data.length} 个可调拨商品`;

                            if (data.length === 0) {
                                productSearch.disabled = true;
                                productSearch.placeholder = '该仓库没有可调拨商品';
                                addProductBtn.disabled = true;
                                noProductsMsg.textContent = '该仓库没有可调拨商品';
                            } else {
                                productSearch.disabled = false;
                                productSearch.placeholder = '点击选择或输入搜索商品';
                                addProductBtn.disabled = false;

                                // 修复单位信息显示
                                data.forEach(product => {
                                    if (product.multi_unit === '1') {
                                        // 确保units存在
                                        if (!product.units) {
                                            product.units = [];
                                        }
                                        // 确保units是一个数组对象
                                        else if (typeof product.units === 'string') {
                                            try {
                                                product.units = JSON.parse(product.units);
                                            } catch (e) {
                                                product.units = [];
                                            }
                                        }
                                    }
                                });
                            }
                        })
                        .catch(error => {
                            console.error('获取仓库商品失败:', error);
                            productCountHint.textContent = '加载失败，请重试';
                            productSearch.disabled = true;
                        });
                }

                // 显示所有商品
                function showAllProducts() {
                    searchResults.innerHTML = '';

                    // 确保有仓库商品
                    if (warehouseProducts.length === 0) {
                        return;
                    }

                    // 按ID降序排序
                    const sortedProducts = [...warehouseProducts].sort((a, b) => b.id - a.id);

                    // 筛选掉已添加的商品
                    const availableProducts = sortedProducts.filter(product =>
                        !productsList.some(p => p.id === product.id)
                    );

                    if (availableProducts.length === 0) {
                        searchResults.innerHTML = '<div class="search-result-item" style="color:#999">所有商品已添加</div>';
                        searchResults.style.display = 'block';
                        return;
                    }

                    // 显示加载提示
                    searchResults.innerHTML = '<div class="search-result-item" style="text-align:center;">加载商品数据...</div>';
                    searchResults.style.display = 'block';

                    // 渲染商品列表
                    renderProductList(availableProducts);
                }

                // 渲染搜索结果列表
                function renderSearchProducts(products) {
                    searchResults.innerHTML = '';
                    renderProductList(products);
                }

                // 统一的产品渲染函数
                function renderProductList(products) {
                    searchResults.innerHTML = '';

                    if (!products || products.length === 0) {
                        searchResults.innerHTML = '<div class="no-results">没有找到商品</div>';
                        return;
                    }

                    let searchResultsHTML = '';
                    products.forEach(product => {
                        const productId = product.id;
                        // 使用stock-number类为基本单位库存添加绿色样式
                        let stockInfo = `库存: <span class="stock-number">${parseFloat(product.stock_quantity).toFixed(2)}</span> ${product.unit}`;

                        // 处理多单位商品
                        if (product.multi_unit == 1 && product.units && product.units.length > 0) {
                            // 为多单位商品构建所有单位的库存信息
                            let unitStocks = [];
                            unitStocks.push(`<span class="stock-number">${parseFloat(product.stock_quantity).toFixed(2)}</span> ${product.unit}`);

                            product.units.forEach(unit => {
                                if (unit.unit_type === 'sub') {
                                    const unitStock = (parseFloat(product.stock_quantity) / parseFloat(unit.ratio)).toFixed(2);
                                    unitStocks.push(`<span class="stock-number">${unitStock}</span> ${unit.unit_name}`);
                                }
                            });

                            // 合并所有单位的库存信息
                            stockInfo = `库存: ${unitStocks.join(', ')}`;
                        }

                        searchResultsHTML += `
                        <div class="search-item" data-product-id="${productId}" data-product-name="${product.product_name}" 
                             data-product-code="${product.product_code}" data-product-unit="${product.unit}" 
                             data-product-multi-unit="${product.multi_unit}" data-product-stock="${product.stock_quantity}">
                            <div class="product-info">
                                <div class="product-code-name">${product.product_code} - ${product.product_name}</div>
                                <div class="stock-info">${stockInfo}</div>
                            </div>
                        </div>`;
                    });

                    searchResults.innerHTML = searchResultsHTML;
                    searchResults.style.display = 'block';

                    // 为搜索结果项添加点击事件
                    const searchItems = searchResults.querySelectorAll('.search-item');
                    searchItems.forEach(item => {
                        item.addEventListener('click', function() {
                            const productId = this.getAttribute('data-product-id');
                            const productName = this.getAttribute('data-product-name');
                            const productCode = this.getAttribute('data-product-code');
                            const productUnit = this.getAttribute('data-product-unit');
                            const multiUnit = this.getAttribute('data-product-multi-unit');
                            const stock = this.getAttribute('data-product-stock');

                            // 获取原始商品数据以获取单位信息
                            const originalProduct = warehouseProducts.find(p => p.id == productId);
                            let units = [];

                            if (originalProduct && originalProduct.units) {
                                units = originalProduct.units;
                                if (typeof units === 'string') {
                                    try {
                                        units = JSON.parse(units);
                                    } catch (e) {
                                        units = [];
                                    }
                                }
                            }

                            // 准备商品数据对象
                            const productData = {
                                id: productId,
                                name: productName,
                                code: productCode,
                                unit: productUnit,
                                multiUnit: multiUnit,
                                stock: stock,
                                units: units
                            };

                            // 添加商品到列表
                            addProductToList(productData);
                        });
                    });
                }

                // 搜索商品
                productSearch.addEventListener('input', function() {
                    if (this.disabled) return;

                    const searchTerm = this.value.toLowerCase();
                    if (searchTerm.length < 1) {
                        showAllProducts();
                        return;
                    }

                    // 筛选符合条件的商品
                    const availableProducts = warehouseProducts.filter(product =>
                        !productsList.some(p => p.id === product.id) &&
                        (product.product_name.toLowerCase().includes(searchTerm) ||
                            product.product_code.toLowerCase().includes(searchTerm))
                    );

                    // 显示结果
                    searchResults.innerHTML = '';

                    if (availableProducts.length === 0) {
                        searchResults.innerHTML = '<div class="search-result-item" style="color:#999">没有找到匹配的商品</div>';
                        searchResults.style.display = 'block';
                        return;
                    }

                    // 显示符合搜索条件的商品列表
                    searchResults.style.display = 'block';
                    renderSearchProducts(availableProducts);
                });

                // 点击外部关闭搜索结果
                document.addEventListener('click', function(e) {
                    if (e.target !== productSearch && e.target !== searchResults && !searchResults.contains(e.target)) {
                        searchResults.style.display = 'none';
                    }
                });

                // 添加商品到列表
                function addProductToList(productData) {
                    // 创建一个新的商品对象
                    const product = {
                        id: productData.id,
                        name: productData.name,
                        code: productData.code,
                        unit: productData.unit,
                        multiUnit: productData.multiUnit,
                        stock: productData.stock,
                        quantity: '', // 移除自动填充，默认为空
                        unitType: 'base', // 默认为基本单位
                        units: [] // 将在加载单位后更新
                    };

                    // 如果已经加载了单位信息，直接使用
                    let hasSubUnits = false;
                    let firstSubUnit = null;

                    if (productData.units && Array.isArray(productData.units) && productData.units.length > 0) {
                        product.units = productData.units;

                        // 查找第一个副单位 (仅用于记录，不再自动选择)
                        for (const unit of productData.units) {
                            if (unit.unit_type === 'sub') {
                                hasSubUnits = true;
                                firstSubUnit = unit;
                                break;
                            }
                        }
                    }
                    // 如果没有单位信息但有多单位，尝试从warehouseProducts中查找预加载的单位信息
                    else if (product.multiUnit === '1') {
                        const originalProduct = warehouseProducts.find(p => p.id == product.id);
                        if (originalProduct && originalProduct.units) {
                            let units = originalProduct.units;
                            // 尝试解析units如果是字符串
                            if (typeof units === 'string') {
                                try {
                                    units = JSON.parse(units);
                                } catch (e) {
                                    units = [];
                                }
                            }

                            if (Array.isArray(units) && units.length > 0) {
                                product.units = units;

                                // 查找第一个副单位 (仅用于记录，不再自动选择)
                                for (const unit of units) {
                                    if (unit.unit_type === 'sub') {
                                        hasSubUnits = true;
                                        firstSubUnit = unit;
                                        break;
                                    }
                                }
                            }
                        }

                        // 如果仍然没有单位信息，检查是否已经在列表中有相同商品且有单位信息
                        if (product.units.length === 0) {
                            const existingProduct = productsList.find(p => p.id == product.id && p.units && p.units.length > 0);
                            if (existingProduct) {
                                product.units = [...existingProduct.units];
                            }
                        }
                    }

                    // 添加到商品列表
                    productsList.push(product);

                    // 更新表格
                    updateProductsTable();

                    // 隐藏搜索结果
                    searchResults.style.display = 'none';
                    productSearch.value = '';
                    productSearchContainer.style.display = 'none';

                    // 如果有多单位但尚未加载单位信息，则加载单位
                    if (product.multiUnit === '1' && product.units.length === 0) {
                        fetchProductUnits(product.id).then(units => {
                            if (units && units.length > 0) {
                                // 找到列表中的所有相同ID的商品并更新单位
                                productsList.forEach((p, index) => {
                                    if (p.id == product.id) {
                                        productsList[index].units = units;

                                        // 刷新单位选择下拉框
                                        updateProductUnits(index);
                                    }
                                });

                                // 刷新商品表格以显示更新后的单位信息
                                updateProductsTable();
                            }
                        }).catch(error => {
                            console.error('获取单位信息失败:', error);
                        });
                    }

                    // 如果有商品，则启用提交按钮
                    submitBtn.disabled = productsList.length === 0;
                }

                // 更新表格中商品显示
                function updateProductsTable() {
                    if (productsList.length === 0) {
                        productsTable.style.display = 'none';
                        noProductsMsg.style.display = 'block';
                        submitBtn.disabled = true;
                        return;
                    }

                    // 显示表格，隐藏提示
                    productsTable.style.display = 'table';
                    noProductsMsg.style.display = 'none';
                    submitBtn.disabled = false;

                    // 清空表格
                    productsBody.innerHTML = '';

                    // 添加每个商品行
                    productsList.forEach((product, index) => {
                        const row = document.createElement('tr');

                        // 商品信息单元格
                        const productCell = document.createElement('td');
                        let productInfo = `${product.name} (${product.code})`;

                        // 添加库存信息
                        productInfo += `<div style="font-size:12px;color:#666;margin-top:3px;">库存: <span class="stock-number">${product.stock}</span> ${product.unit}`;

                        // 如果有多单位，显示所有单位的库存
                        if (product.multiUnit === '1' && product.units && product.units.length > 0) {
                            let subUnitCount = 0;

                            product.units.forEach(unit => {
                                if (unit.unit_type === 'sub') {
                                    subUnitCount++;
                                    const ratio = parseFloat(unit.ratio);
                                    if (ratio > 0) {
                                        const subUnitStock = (parseFloat(product.stock) / ratio).toFixed(2);
                                        productInfo += `, <span class="stock-number">${subUnitStock}</span> ${unit.unit_name}`;
                                    }
                                }
                            });
                        }

                        productInfo += '</div>';

                        productCell.innerHTML = productInfo + `<input type="hidden" name="products[]" value="${product.id}">`;
                        row.appendChild(productCell);

                        // 数量单元格
                        const quantityCell = document.createElement('td');
                        const quantityInput = document.createElement('input');
                        quantityInput.type = 'number';
                        quantityInput.className = 'form-input';
                        quantityInput.name = 'quantities[]';
                        quantityInput.min = '0.01';
                        quantityInput.step = '0.01';
                        quantityInput.value = product.quantity;
                        quantityInput.max = product.stock;
                        quantityInput.required = true;
                        quantityInput.placeholder = '请输入数量';
                        quantityInput.addEventListener('change', function() {
                            product.quantity = parseFloat(this.value);
                        });
                        quantityCell.appendChild(quantityInput);
                        row.appendChild(quantityCell);

                        // 单位单元格
                        const unitCell = document.createElement('td');
                        const unitSelect = document.createElement('select');
                        unitSelect.className = 'form-select';
                        unitSelect.name = 'unit_types[]';
                        unitSelect.id = `unit-select-${index}`;

                        // 添加基本单位选项
                        const baseOption = document.createElement('option');
                        baseOption.value = 'base';
                        baseOption.textContent = product.unit;
                        if (product.unitType === 'base') {
                            baseOption.selected = true;
                        }
                        unitSelect.appendChild(baseOption);

                        // 保存单位选择器引用，以便后续更新
                        product.unitSelectElement = unitSelect;

                        // 添加已经加载的其他单位
                        let hasSubUnits = false;
                        if (product.units && product.units.length > 0) {
                            product.units.forEach(unit => {
                                if (unit.unit_type === 'sub') {
                                    hasSubUnits = true;
                                    const option = document.createElement('option');
                                    option.value = unit.unit_name;
                                    option.textContent = unit.unit_name;

                                    // 如果当前单位类型与该单位名称匹配，则选中该选项
                                    if (product.unitType === unit.unit_name) {
                                        option.selected = true;
                                    }

                                    unitSelect.appendChild(option);
                                }
                            });
                        }

                        unitSelect.addEventListener('change', function() {
                            product.unitType = this.value;
                        });

                        unitCell.appendChild(unitSelect);
                        row.appendChild(unitCell);

                        // 操作单元格
                        const actionCell = document.createElement('td');
                        const deleteBtn = document.createElement('button');
                        deleteBtn.type = 'button';
                        deleteBtn.className = 'delete-row-btn';
                        deleteBtn.textContent = '删除';
                        deleteBtn.addEventListener('click', function() {
                            removeProduct(index);
                        });
                        actionCell.appendChild(deleteBtn);
                        row.appendChild(actionCell);

                        // 将行添加到表格
                        productsBody.appendChild(row);
                    });
                }

                // 更新商品的单位选择器
                function updateProductUnits(productIndex) {
                    const product = productsList[productIndex];
                    if (!product) {
                        return;
                    }

                    if (!product.unitSelectElement) {
                        return;
                    }

                    const unitSelect = product.unitSelectElement;
                    if (!unitSelect) {
                        return;
                    }

                    // 保留基本单位选项
                    unitSelect.innerHTML = '';

                    // 添加基本单位
                    const baseOption = document.createElement('option');
                    baseOption.value = 'base';
                    baseOption.textContent = product.unit;
                    if (product.unitType === 'base') {
                        baseOption.selected = true;
                    }
                    unitSelect.appendChild(baseOption);

                    // 添加其他单位
                    let hasSubUnits = false;
                    if (product.units && product.units.length > 0) {
                        // 先找到当前设置的unitType对应的unit
                        let selectedUnitExists = product.unitType === 'base';
                        if (product.unitType !== 'base') {
                            selectedUnitExists = product.units.some(u => u.unit_name === product.unitType);
                        }

                        product.units.forEach(unit => {
                            if (unit.unit_type === 'sub') {
                                hasSubUnits = true;
                                const option = document.createElement('option');
                                option.value = unit.unit_name;
                                option.textContent = unit.unit_name;

                                // 如果当前商品的unitType设置为此单位，则选中
                                if (product.unitType === unit.unit_name) {
                                    option.selected = true;
                                }

                                unitSelect.appendChild(option);
                            }
                        });

                        // 如果当前设置的unitType不存在于单位列表中，默认选择第一个副单位
                        if (!selectedUnitExists && hasSubUnits) {
                            const firstSubUnit = product.units.find(u => u.unit_type === 'sub');
                            if (firstSubUnit) {
                                product.unitType = firstSubUnit.unit_name;

                                // 更新选择器选中项
                                for (let i = 0; i < unitSelect.options.length; i++) {
                                    if (unitSelect.options[i].value === firstSubUnit.unit_name) {
                                        unitSelect.options[i].selected = true;
                                        break;
                                    }
                                }
                            }
                        }
                    }
                }

                // 从列表中移除商品
                function removeProduct(index) {
                    productsList.splice(index, 1);
                    updateProductsTable();
                }

                // 获取商品单位
                function fetchProductUnits(productId) {
                    return fetch(`get_product_units.php?product_id=${productId}`)
                        .then(response => {
                            if (!response.ok) {
                                throw new Error(`请求失败: ${response.status} ${response.statusText}`);
                            }
                            return response.json();
                        })
                        .then(data => {
                            if (Array.isArray(data)) {
                                if (data.length > 0) {
                                    // 处理每个单位，确保数据格式正确
                                    data.forEach((unit) => {
                                        // 确保ratio是数字
                                        if (unit.ratio) {
                                            unit.ratio = parseFloat(unit.ratio);
                                        }
                                    });
                                }
                            } else if (data.error) {
                                return [];
                            }

                            productUnits = data;
                            return data;
                        })
                        .catch(error => {
                            console.error(`获取商品单位信息失败:`, error);
                            return [];
                        });
                }

                // 目标仓库改变时检查是否与源仓库相同
                targetWarehouseSelect.addEventListener('change', function() {
                    const sourceWarehouse = sourceWarehouseSelect.value;
                    const targetWarehouse = this.value;

                    if (sourceWarehouse && targetWarehouse && sourceWarehouse === targetWarehouse) {
                        alert('源仓库和目标仓库不能相同!');
                        this.value = '';
                    }
                });

                // 源仓库和目标仓库不能相同的检查
                document.getElementById('transfer-form').addEventListener('submit', function(e) {
                    const sourceWarehouse = document.getElementById('source_warehouse_id').value;
                    const targetWarehouse = document.getElementById('target_warehouse_id').value;

                    if (!sourceWarehouse || !targetWarehouse) {
                        e.preventDefault();
                        alert('请选择源仓库和目标仓库!');
                        return;
                    }

                    if (sourceWarehouse === targetWarehouse) {
                        e.preventDefault();
                        alert('源仓库和目标仓库不能相同!');
                        return;
                    }

                    if (productsList.length === 0) {
                        e.preventDefault();
                        alert('请至少添加一个商品!');
                        return;
                    }

                    // 检查每个商品的数量
                    let hasInvalidQuantity = false;
                    productsList.forEach((product, index) => {
                        const quantity = parseFloat(document.getElementsByName('quantities[]')[index].value);
                        if (isNaN(quantity) || quantity <= 0) {
                            e.preventDefault();
                            alert(`商品 ${product.name} 的调拨数量无效!`);
                            hasInvalidQuantity = true;
                            return;
                        }

                        if (quantity > product.stock) {
                            e.preventDefault();
                            alert(`商品 ${product.name} 的调拨数量不能超过库存 ${product.stock}!`);
                            hasInvalidQuantity = true;
                            return;
                        }
                    });

                    if (hasInvalidQuantity) {
                        return;
                    }
                });

                // 自动关闭消息提示
                setTimeout(() => {
                    const messageBox = document.getElementById('message-container');
                    if (messageBox) {
                        messageBox.style.display = 'none';
                    }
                }, 3000);
            });
        <?php endif; ?>
    </script>
</body>

</html>