<?php
// save_warehouse.php
session_start();
if (!isset($_SESSION['user'])) {
    exit('❌ 无权限访问');
}

// 引入数据库配置文件
require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 检查是否为POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    exit('❌ 无效的请求方法');
}

// 获取表单数据
$action = $_POST['action'] ?? '';
$name = trim($_POST['name'] ?? '');
$location = trim($_POST['location'] ?? '');
$manager = trim($_POST['manager'] ?? '');
$phone = trim($_POST['phone'] ?? '');

// 验证必填字段
if (empty($name)) {
    exit('❌ 仓库名称不能为空');
}

try {
    if ($action === 'add') {
        // 添加新仓库
        $stmt = $conn->prepare("INSERT INTO warehouses (name, location, manager, phone) VALUES (?, ?, ?, ?)");
        $stmt->bind_param("ssss", $name, $location, $manager, $phone);

        if ($stmt->execute()) {
            echo "✅ 仓库添加成功！";
        } else {
            throw new Exception("添加失败：" . $stmt->error);
        }
    } elseif ($action === 'edit') {
        // 更新仓库
        $id = (int)$_POST['id'];
        if ($id <= 0) {
            throw new Exception("无效的仓库ID");
        }

        $stmt = $conn->prepare("UPDATE warehouses SET name = ?, location = ?, manager = ?, phone = ? WHERE id = ?");
        $stmt->bind_param("ssssi", $name, $location, $manager, $phone, $id);

        if ($stmt->execute()) {
            echo "✅ 仓库更新成功！";
        } else {
            throw new Exception("更新失败：" . $stmt->error);
        }
    } else {
        throw new Exception("无效的操作类型");
    }
} catch (Exception $e) {
    echo "❌ " . $e->getMessage();
} finally {
    if (isset($stmt)) {
        $stmt->close();
    }
    $conn->close();
}
