<?php
// supplier.php
session_start();
if (!isset($_SESSION['user'])) {
    header("Location: ../login.php");
    exit;
}

require_once '../config.php';

// 数据库连接
$conn = get_db_connection();

// 获取供应商列表
$suppliers = [];
$result = $conn->query("SELECT * FROM suppliers ORDER BY created_at DESC");
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $suppliers[] = $row;
    }
    $result->close();
}

$conn->close();
?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>供应商管理</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>供应商管理</h2>
        <div class="button-group">
            <button class="btn btn-add" onclick="showAddForm()">新增供应商</button>
        </div>
    </div>

    <!-- 消息显示 -->
    <div id="message-container" class="message" style="display: none;">
        <span id="message-text"></span>
        <button onclick="document.getElementById('message-container').style.display='none'">×</button>
    </div>

    <!-- 添加供应商表单 -->
    <div id="add-form" class="container" style="display: none;">
        <h3>新增供应商</h3>
        <form action="save_supplier.php" method="post" target="response-frame" id="supplier-form">
            <input type="hidden" name="action" value="add">
            <div class="form-row">
                <div class="form-col">
                    <label>供应商名称：</label>
                    <input type="text" name="name" required>
                </div>
                <div class="form-col">
                    <label>联系人：</label>
                    <input type="text" name="contact_person">
                </div>
            </div>
            <div class="form-row">
                <div class="form-col">
                    <label>联系电话：</label>
                    <input type="text" name="phone">
                </div>
                <div class="form-col">
                    <label>地址：</label>
                    <input type="text" name="address">
                </div>
            </div>
            <div class="form-row">

            </div>
            <div class="btn-group">
                <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                <button type="submit" class="btn btn-success">保存</button>
            </div>
        </form>
    </div>

    <!-- 供应商列表 -->
    <div class="container">
        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>供应商名称</th>
                        <th>联系人</th>
                        <th>联系电话</th>
                        <th>地址</th>
                        <th>创建时间</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($suppliers)): ?>
                        <tr>
                            <td colspan="5" style="text-align: center;">暂无供应商数据</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($suppliers as $supplier): ?>
                            <tr>
                                <td><?= htmlspecialchars($supplier['name']) ?></td>
                                <td><?= htmlspecialchars($supplier['contact_person'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($supplier['phone'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($supplier['address'] ?: '-') ?></td>
                                <td><?= $supplier['created_at'] ?></td>
                                <td>
                                    <a href="edit_supplier.php?id=<?= $supplier['id'] ?>" class="btn">编辑</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- 隐藏iframe用于接收返回 -->
    <iframe name="response-frame" id="response-frame" style="display:none;"></iframe>

    <script>
        // 显示/隐藏表单
        function showAddForm() {
            document.getElementById('add-form').style.display = 'block';
        }

        function hideAddForm() {
            document.getElementById('add-form').style.display = 'none';
            document.getElementById('supplier-form').reset();
        }

        // 提交完成后显示返回消息
        document.getElementById('response-frame').onload = function() {
            try {
                var response = this.contentWindow.document.body.innerHTML;
                if (response.includes("✅")) {
                    hideAddForm();
                    showMessage(response);
                    setTimeout(function() {
                        window.location.reload();
                    }, 1000);
                } else if (response.includes("❌")) {
                    showMessage(response);
                }
            } catch (e) {}
        };

        function showMessage(text) {
            const box = document.getElementById("message-container");
            document.getElementById("message-text").innerText = text;
            box.style.display = "flex";
            setTimeout(() => box.style.display = "none", 3000);
        }
    </script>
</body>

</html>