<?php
session_start();
if (!isset($_SESSION['user']) || $_SESSION['user']['role'] !== 'admin') {
    exit('❌ 无权限访问');
}

// 数据库连接
require_once '../config.php';
$conn = get_db_connection();

if ($conn->connect_error) {
    die("连接失败: " . $conn->connect_error);
}

// 获取用户ID
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;
if ($id <= 0) {
    die('❌ 参数错误');
}

// 获取用户信息
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    die('❌ 用户不存在');
}

?>
<!DOCTYPE html>
<html lang="zh">

<head>
    <meta charset="UTF-8">
    <title>编辑用户</title>
    <link rel="stylesheet" href="style.css">
</head>

<body>
    <div class="header">
        <h2>编辑用户</h2>
        <a href="list_users.php" class="btn btn-secondary">返回列表</a>
    </div>

    <div class="container">
        <form action="update_user.php" method="post">
            <input type="hidden" name="id" value="<?= $user['id'] ?>">

            <div class="form-group">
                <label>用户名:</label>
                <input type="text" name="username" value="<?= htmlspecialchars($user['username']) ?>" required>
            </div>

            <div class="form-group">
                <label>密码:</label>
                <input type="password" name="password" placeholder="留空则不修改密码">
            </div>

            <div class="form-group">
                <label>姓名:</label>
                <input type="text" name="real_name" value="<?= htmlspecialchars($user['real_name']) ?>">
            </div>

            <div class="form-group">
                <label>角色:</label>
                <select name="role" required>
                    <option value="admin" <?= $user['role'] == 'admin' ? 'selected' : '' ?>>系统管理员</option>
                    <option value="finance" <?= $user['role'] == 'finance' ? 'selected' : '' ?>>财务</option>
                    <option value="user" <?= $user['role'] == 'user' ? 'selected' : '' ?>>普通用户</option>
                </select>
            </div>

            <div class="form-group">
                <label>邮箱:</label>
                <input type="email" name="email" value="<?= htmlspecialchars($user['email']) ?>">
            </div>

            <div class="form-group">
                <label>联系电话:</label>
                <input type="text" name="phone" value="<?= htmlspecialchars($user['phone']) ?>">
            </div>

            <div class="form-group form-col-checkbox">
                <label>启用状态:</label>
                <input type="checkbox" name="is_active" value="1" <?= $user['is_active'] ? 'checked' : '' ?>>
            </div>

            <div class="btn-group">
                <button type="submit" class="btn">保存修改</button>
            </div>
        </form>
    </div>
</body>

</html>