<?php
session_start();
if (!isset($_SESSION['user']) || $_SESSION['user']['role'] !== 'admin') {
    exit('❌ 无权限访问');
}

// 数据库连接
require_once '../config.php';
$conn = get_db_connection();

if ($conn->connect_error) {
    die("连接失败: " . $conn->connect_error);
}

// 获取并校验参数
$id = intval($_POST['id']);
$username = trim($_POST['username']);
$password = trim($_POST['password']);
$real_name = trim($_POST['real_name']);
$role = $_POST['role'];
$email = trim($_POST['email']);
$phone = trim($_POST['phone']);
$is_active = isset($_POST['is_active']) ? 1 : 0;

// 基本校验
if ($id <= 0 || $username === '' || !in_array($role, ['admin', 'finance', 'user'])) {
    die("❌ 参数错误");
}

// 检查用户名是否重复（排除自身）
$check = $conn->prepare("SELECT id FROM users WHERE username = ? AND id != ?");
$check->bind_param("si", $username, $id);
$check->execute();
$res = $check->get_result();
if ($res->num_rows > 0) {
    die("❌ 用户名已存在");
}

// 构建 SQL
if ($password !== '') {
    // 修改密码
    $hashed_password = password_hash($password, PASSWORD_DEFAULT);
    $sql = "UPDATE users SET username=?, password=?, real_name=?, role=?, email=?, phone=?, is_active=? WHERE id=?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ssssssii", $username, $hashed_password, $real_name, $role, $email, $phone, $is_active, $id);
} else {
    // 不修改密码
    $sql = "UPDATE users SET username=?, real_name=?, role=?, email=?, phone=?, is_active=? WHERE id=?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ssssssi", $username, $real_name, $role, $email, $phone, $is_active, $id);
}

// 执行更新
if ($stmt->execute()) {
    header("Location: list_users.php?message= 用户已更新");
    exit;
} else {
    die("❌ 更新失败: " . $stmt->error);
}
